@@ -1,6 +1,6 @@
 ###
 # Copyright (c) 2002-2004, Jeremiah Fincher
-# Copyright (c) 2009-2010, James McCoy
+# Copyright (c) 2014, James McCoy
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -81,9 +81,6 @@ def getArgs(args, required=1, optional=0, wildcard=0):
 class AliasError(Exception):
     pass
 
-class RecursiveAlias(AliasError):
-    pass
-
 dollarRe = re.compile(r'\$(\d+)')
 def findBiggestDollar(alias):
     dollars = dollarRe.findall(alias)
@@ -214,11 +211,11 @@ def makeNewAlias(name, alias):
                         return True
                 return False
             everythingReplace(tokens)
-        maxNesting = conf.supybot.commands.nested.maximum()
-        if maxNesting and irc.nested+1 > maxNesting:
-            irc.error(_('You\'ve attempted more nesting than is '
-                  'currently allowed on this bot.'), Raise=True)
-        self.Proxy(irc, msg, tokens, nested=irc.nested+1)
+        # Limit memory use by constraining the size of the message being passed
+        # in to the alias.  Also tracking nesting to avoid endless recursion.
+        maxLength = conf.supybot.reply.maximumLength()
+        tokens = [t[:maxLength] for t in tokens]
+        self.Proxy(irc, msg, tokens, nested=irc.nested + 1)
     flexargs = ''
     if biggestDollar and (wildcard or biggestAt):
         flexargs = _(' at least')
@@ -343,11 +340,8 @@ class Alias(callbacks.Plugin):
             (currentAlias, locked, _) = self.aliases[name]
             if locked and currentAlias != alias:
                 raise AliasError(format('Alias %q is locked.', name))
-        try:
-            f = makeNewAlias(name, alias)
-            f = types.MethodType(f, self)
-        except RecursiveAlias:
-            raise AliasError('You can\'t define a recursive alias.')
+        f = makeNewAlias(name, alias)
+        f = types.MethodType(f, self)
         if '.' in name or '|' in name:
             aliasGroup = self.registryValue('escapedaliases', value=False)
             confname = escapeAlias(name)
