@@ -56,8 +56,15 @@ class Internet(callbacks.Plugin):
                 irc.reply(hostname)
         else:
             try:
-                ip = socket.getaddrinfo(host, None)[0][4][0]
-                irc.reply(ip)
+                ips = socket.getaddrinfo(host, None)
+                ips = map(lambda x:x[4][0], ips)
+                ordered_unique_ips = []
+                unique_ips = set()
+                for ip in ips:
+                    if ip not in unique_ips:
+                        ordered_unique_ips.append(ip)
+                        unique_ips.add(ip)
+                irc.reply(format('%L', ordered_unique_ips))
             except socket.error:
                 irc.reply(_('Host not found.'))
     dns = wrap(dns, ['something'])
