@@ -28,6 +28,7 @@
 ###
 
 import os
+import sys
 import time
 import string
 
@@ -106,11 +107,13 @@ class SqliteMoobotDB(object):
         
         if os.path.exists(filename):
             db = sqlite3.connect(filename, check_same_thread=False)
-            db.text_factory = str
+            if sys.version_info[0] < 3:
+                db.text_factory = str
             self.dbs[channel] = db
             return db
         db = sqlite3.connect(filename, check_same_thread=False)
-        db.text_factory = str
+        if sys.version_info[0] < 3:
+            db.text_factory = str
         self.dbs[channel] = db
         cursor = db.cursor()
         cursor.execute("""CREATE TABLE factoids (
