@@ -228,7 +228,7 @@ class Topic(callbacks.Plugin):
         c = irc.state.channels[channel]
         if msg.nick in c.ops or msg.nick in c.halfops or 't' not in c.modes:
             return True
-        capabilities = self.registryValue('requireManageCapability')
+        capabilities = self.registryValue('requireManageCapability', channel)
         if capabilities:
             for capability in re.split(r'\s*;\s*', capabilities):
                 if capability.startswith('channel,'):
