@@ -374,7 +374,8 @@ registerChannelValue(supybot.reply.format, 'time',
 def timestamp(t):
     if t is None:
         t = time.time()
-    t = time.localtime(t)
+    if isinstance(t, float) or isinstance(t, int):
+        t = time.localtime(t)
     format = get(supybot.reply.format.time, dynamic.channel)
     return time.strftime(format, t)
 utils.str.timestamp = timestamp
@@ -558,7 +559,7 @@ registerChannelValue(supybot.replies, 'error',
 
 registerChannelValue(supybot.replies, 'errorOwner',
     registry.NormalizedString(_("""An error has occurred and has been logged.
-    Check the logs for more informations."""), _("""Determines what error
+    Check the logs for more information."""), _("""Determines what error
     message the bot gives to the owner when it wants to be ambiguous.""")))
 
 registerChannelValue(supybot.replies, 'incorrectAuthentication',
@@ -676,12 +677,12 @@ class ValidBrackets(registry.OnlySomeStrings):
     validStrings = ('', '[]', '<>', '{}', '()')
 
 registerChannelValue(supybot.commands.nested, 'brackets',
-    ValidBrackets('[]', _("""Supybot allows you to specify what brackets are
-    used for your nested commands.  Valid sets of brackets include [], <>, and
-    {} ().  [] has strong historical motivation, as well as being the brackets
-    that don't require shift.  <> or () might be slightly superior because they
-    cannot occur in a nick.  If this string is empty, nested commands will
-    not be allowed in this channel.""")))
+    ValidBrackets('[]', _("""Supybot allows you to specify what brackets
+    are used for your nested commands.  Valid sets of brackets include
+    [], <>, {}, and ().  [] has strong historical motivation, but <> or
+    () might be slightly superior because they cannot occur in a nick.
+    If this string is empty, nested commands will not be allowed in this
+    channel.""")))
 registerChannelValue(supybot.commands.nested, 'pipeSyntax',
     registry.Boolean(False, _("""Supybot allows nested commands. Enabling this
     option will allow nested commands with a syntax similar to UNIX pipes, for
@@ -1058,11 +1059,11 @@ registerChannelValue(supybot.protocols.irc, 'banmask',
     default banmask style.""")))
 
 registerGlobalValue(supybot.protocols.irc, 'strictRfc',
-    registry.Boolean(True, _("""Determines whether the bot will strictly follow
-    the RFC; currently this only affects what strings are considered to be
-    nicks. If you're using a server or a network that requires you to message
-    a nick such as services@this.network.server then you you should set this to
-    False.""")))
+    registry.Boolean(False, _("""Determines whether the bot will strictly
+    follow the RFC; currently this only affects what strings are
+    considered to be nicks. If you're using a server or a network that
+    requires you to message a nick such as services@this.network.server
+    then you you should set this to False.""")))
 
 registerGlobalValue(supybot.protocols.irc, 'certfile',
     registry.String('', _("""Determines what certificate file (if any) the bot
@@ -1169,9 +1170,9 @@ registerGlobalValue(supybot.servers.http, 'favicon',
 ###
 registerGlobalValue(supybot, 'defaultIgnore',
     registry.Boolean(False, _("""Determines whether the bot will ignore
-    unregistered users by default.  Of course, that'll make it particularly
-    hard for those users to register or identify with the bot, but that's your
-    problem to solve.""")))
+    unidentified users by default.  Of course, that'll make it
+    particularly hard for those users to register or identify with the bot
+    without adding their hostmasks, but that's your problem to solve.""")))
 
 
 registerGlobalValue(supybot, 'externalIP',
